@@ -4,88 +4,6 @@
 #include <Rdefines.h>
 #include <R_ext/Utils.h>
 #include <ctype.h>
-/* 
-   speed up the conversion, this could become as.environment at some
-   time
-   we might want to check the names though
-
-*/
-
-SEXP listLen(SEXP x)
-{
-  SEXP ans;
-  int i;
-  int *lens;
-
-  if (!Rf_isNewList(x))
-      error("arg 'x' must be a 'list', not '%s'", type2char(TYPEOF(x)));
-
-  PROTECT(ans = allocVector(INTSXP, length(x)));
-  lens = INTEGER(ans);
-  for(i = 0; i < length(x); i++)
-    lens[i] = length(VECTOR_ELT(x, i));
-  UNPROTECT(1);
-  return(ans);
-}
-
-SEXP copyEnv(SEXP e1, SEXP e2, SEXP all)
-{
-    SEXP nms, sym, val;
-    int i, all_nms;
-
-    if (!(isEnvironment(e1) && isEnvironment(e2) && isLogical(all)))
-        error("invalid arguments");
-    all_nms = INTEGER(all)[0];
-    if (all_nms == NA_LOGICAL)
-        error("arg 'all' must be TRUE or FALSE, not NA");
-
-    PROTECT(nms = R_lsInternal(e1, all_nms));
-    for (i = 0; i < length(nms); i++) {
-        /* no inheritance in lookup */
-        PROTECT(sym = install(CHAR(STRING_ELT(nms, i))));
-        val = findVarInFrame3(e1, sym, TRUE);
-        INCREMENT_NAMED(val);
-        defineVar(sym, val, e2);
-        UNPROTECT(1);
-    }
-    UNPROTECT(1);
-    return(e2);
-}
-
-SEXP listToEnv(SEXP x, SEXP env)
-{
-  SEXP name, nm, nx, sym;
-  int i;
-
-  if( !Rf_isNewList(x) )
-      error("first argument must be a list, found %s",
-            type2char(TYPEOF(x)));
-
-  if( !isEnvironment(env) )
-      error("second argument must be an environment, found %s",
-            type2char(TYPEOF(env)));
-
-  PROTECT(nm = getAttrib(x, R_NamesSymbol));
-  if( length(nm) != length(x) )
-    error("all elements must have names");
-
-  for( i=0; i<length(nm); i++) {
-    name = STRING_ELT(nm, i);
-    if (name == NA_STRING)
-        error("list element %d has NA as name", i + 1);
-    if (length(name) == 0)
-        error("list element %d has \"\" as name", i + 1);
-    sym = Rf_install(CHAR(name));
-    PROTECT(nx = Rf_duplicate(VECTOR_ELT(x, i)));
-    Rf_defineVar(sym, nx, env);
-    UNPROTECT(1);
-  }
-
-  UNPROTECT(1);
-  if (length(nm) != length(env))
-      warning("encountered duplicate names in input list");
-  return(env);
-}
 
 /* fast computation of row order statistics */
 
